package com.akamai.ads.sample;

import com.akamai.analytics.trackers.ComscoreTracker;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.ui.listeners.IMediaPlayerControllerListener;
import com.akamai.ui.media.MediaPlayerController;
import com.akamai.webvtt.captioner.CaptionComponent;

import android.os.Bundle;
import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.view.Menu;
import android.widget.FrameLayout.LayoutParams;
import android.widget.LinearLayout;
import android.widget.ProgressBar;
import android.widget.RelativeLayout;

// Sample application
// Implements:
// - Events management
// - Playback support for live and vod streams
// - Seeking support 
public class Activity_Feed_Asset extends Activity implements IMediaPlayerControllerListener
{
	// Video Player container object
	private VideoPlayerContainer mVideoPlayerContainer;
	
	// Video Player object
	private VideoPlayerView mVideoPlayer;

	// Control bar component
	private MediaPlayerController mMediaPlayerController;
	
	// Comscore plugin
	private ComscoreTracker mComscoreTracker;
	
	// Captioning plugin
	private CaptionComponent mCaptionComponent;
	
	// Progress bar control
	private ProgressBar mProgressBar;
	
	// Media Asset url
	private final String MEDIA_ASSET_URL = "http://projects.mediadev.edgesuite.net/customers/akamai/mdt-html5-core/premier/1.0.0008/resources/feeds/vod-feed.json";
	
	// Android SDK License
	private final String ANDROID_SDK_LICENSE = "BDGwrYmK2CdPurFiGek-gfFAqYtS3W1aTVD_S9s5XmL2U1J_3b5qEuiaH7WOMLszuBjkCei4VjQEw4Fi9UbweA==";
	
	// Keep current fullscreen mode
	private boolean mFullScreenMode = false;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.video_player_layout);
        
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        
        setupVideoPlayerComponents();
    }
    
    private void setupVideoPlayerComponents()
    {
    	mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.setMode(VideoPlayerContainer.MODE_HARDWARE_ADVANCED);
        mVideoPlayer = mVideoPlayerContainer.getVideoPlayer();
        mVideoPlayer.setLicense(ANDROID_SDK_LICENSE);  
        mVideoPlayer.setAutoResume(true);

        // UI Control bar
        mMediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);
   
        // Analytics config
        mComscoreTracker = new ComscoreTracker();
        mComscoreTracker.enableReporting(false); // set to false here because we are not configuring Comscore in this example
        mComscoreTracker.init(this);
        
        // Captions
        mCaptionComponent = (CaptionComponent) findViewById(R.id.captionView);
        
        // Components config
        mMediaPlayerController.setVideoPlayerView(mVideoPlayer);
        mComscoreTracker.setVideoPlayerView(mVideoPlayer);
        mCaptionComponent.setVideoPlayerView(mVideoPlayer);

        // Set this object to listen SDK events and start playing the url
        mVideoPlayer.setProgressBarControl(mProgressBar);
        
        // Listen to control bar events
        mMediaPlayerController.setEventsListener(this);
        
        // Play Url
        mVideoPlayer.playFeedFromUrl(MEDIA_ASSET_URL);
    }
    
 
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }

    
   


	@Override
    protected void onResume() 
    {	
		if(mVideoPlayer != null)
			mVideoPlayer.onResume();
		
        super.onResume();
    }
	
	@Override
    protected void onPause() 
    {	
		if(mVideoPlayer != null)
			mVideoPlayer.onPause();
		
        super.onPause();
    }
	

	@Override
    protected void onDestroy() 
    {	
		mVideoPlayer.stop();
		mVideoPlayer.onDestroy();
        super.onDestroy();
    }
	
	@Override
	public void onConfigurationChanged(Configuration newConfig) {
	    super.onConfigurationChanged(newConfig);

	    // Checks the orientation of the screen
	    if (newConfig.orientation == Configuration.ORIENTATION_LANDSCAPE) 
	    {
	    	setFullScreenMode(true);
	    } 
	    else if (newConfig.orientation == Configuration.ORIENTATION_PORTRAIT)
	    {
	    	setFullScreenMode(false);
	    }
	}

	
	private void setFullScreenMode(boolean fullscreen)
	{
		if(fullscreen == mFullScreenMode)
			return;
		
	    // Checks the orientation of the screen
	    if (fullscreen) 
	    {
	    	setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);  
	    	
	        //View t1 = (View)findViewById(R.id.textView1);
	        //View t2 = (View)findViewById(R.id.textView2);
	        //t1.setVisibility(View.GONE);
	        //t2.setVisibility(View.GONE);
	        
	        RelativeLayout playerContainer = (RelativeLayout) findViewById(R.id.playerContainer);
	        
	        LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.FILL_PARENT);
	        playerContainer.setLayoutParams(params);
	        
	        mVideoPlayerContainer.requestLayout();
	    } 
	    else if (!fullscreen)
	    {
	    	setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);  
	    	
	    	//View t1 = (View)findViewById(R.id.textView1);
	        //View t2 = (View)findViewById(R.id.textView2);
	        //t1.setVisibility(View.VISIBLE);
	        //t2.setVisibility(View.VISIBLE);
	        
	        RelativeLayout playerContainer = (RelativeLayout) findViewById(R.id.playerContainer);
	        LinearLayout.LayoutParams params = new LinearLayout.LayoutParams(LayoutParams.FILL_PARENT, (int)getResources().getDimension(R.dimen.player_height));
	        playerContainer.setLayoutParams(params);
	        
	        mVideoPlayerContainer.requestLayout();
	    }
	    
	    mFullScreenMode = fullscreen;
	}
	
	
	@Override
	public void onButtonClicked(int arg0) {
		if(arg0 == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_FULLSCREEN)
			setFullScreenMode(!mFullScreenMode);
	}
}

	
